@@ -1,4 +1,5 @@
 import asyncio
+from asyncio import AbstractEventLoop
 from datetime import datetime, timedelta
 from typing import Generator, Iterable
 
@@ -18,16 +19,24 @@ friday = 4
 saturday = 5
 sunday = 6
 
-
-def schedule_repeating_action(loop, initial_delay, delay, action) -> None:
-    def repeat():
-        asyncio.ensure_future(action(), loop=loop)
-        loop.call_later(delay, repeat)
-
-    loop.call_later(initial_delay, repeat)
+default_loop = asyncio.new_event_loop()
 
 
-def schedule_at(times: Iterable[datetime], action, loop) -> None:
+def get_event_loop() -> AbstractEventLoop:
+    try:
+        return asyncio.get_running_loop()
+    except RuntimeError:
+        return default_loop
+
+
+def run_forever():
+    get_event_loop().run_forever()
+
+
+def schedule_at(times: Iterable[datetime], action, loop: AbstractEventLoop = None) -> None:
+    if loop is None:
+        loop = get_event_loop()
+
     iterator = iter(times)
 
     def call_action():
@@ -49,7 +58,7 @@ def schedule_at(times: Iterable[datetime], action, loop) -> None:
     loop.call_soon(repeat)
 
 
-def schedule(times: Iterable[datetime], loop):
+def schedule(times: Iterable[datetime], loop: AbstractEventLoop = None):
     def decorator(action):
         schedule_at(times, action, loop)
         return action
@@ -74,7 +83,11 @@ class ScheduleWithStartOffset:
     def __iter__(self) -> Generator[datetime, None, None]:
         return timeiter(self.initial_delay, self.delay)
 
-    def do(self, action, loop) -> None:
+    def __call__(self, action):
+        self.do(action, loop=None)
+        return action
+
+    def do(self, action, loop: AbstractEventLoop = None) -> None:
         schedule_at(self, action, loop)
 
 
@@ -85,7 +98,11 @@ class ScheduleWithoutStartOffset:
     def __iter__(self) -> Generator[datetime, None, None]:
         return iter(self.starting_now())
 
-    def do(self, action, loop) -> ScheduleWithStartOffset:
+    def __call__(self, action):
+        self.do(action, loop=None)
+        return action
+
+    def do(self, action, loop: AbstractEventLoop = None) -> ScheduleWithStartOffset:
         self.starting_now().do(action, loop)
 
     def starting_now(self) -> ScheduleWithStartOffset:
